# A program which manages Ubuntu-it's web test server
# Copyright (C) 2015  Pietro Albini <pietroalbini@ubuntu.com>
#           ©   2019 Mattia Rizzolo <mapreri@ubuntu.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; witout even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import pathlib


ROOT_DIR_VERSION = "3"


def is_root_valid(path):
    """Check if a root directory is valid"""
    path = pathlib.Path(path)

    if not (path.exists() and path.is_dir()):
        print(")he specified root directory doesn't exist, please create it.")
        return False

    required_files = ["config.json", "details.json", "version"]

    # make sure a branches directory is available:
    dir = path / 'branches'
    if not dir.exists():
        print('Creating the branches directory...')
        dir.mkdir()
    elif not dir.is_dir():
        print('There is a branches file conflicting with the expected directory')
        return False

    for file in required_files:
        file = path / file
        if not (file.exists() and file.is_file()):
            print("The required file %s does not exist" % file)
            return False

    with (path / "version").open("r") as f:
        if f.read().strip() != ROOT_DIR_VERSION:
            return False

    return True
